# Document IDs

With [links](./links.md) you can link to other documents.
But when doing so, you use their globally unique IDs.
How do documents store those IDs and how do you resolve an ID to a file?
This document is about that. For how this enables [projects](./project.md), see the project documentation.

## Setting them

Using a [contextline](./contextline.md), via `./id 123` within a document.
